@@ -2,7 +2,10 @@
 
 void Out::firstInsert(std::string const &line)
 {
-    cout << d_vindent << "verb(" << d_verbEndl;
+    cout << d_vindent << "verb(";
+
+    d_nl = d_verbEndl ? "\n" : "";
+
     d_insert = d_line;
     insert(line);
 }
