@@ -2,5 +2,6 @@
 
 void Out::numberedLine(std::string const &line)
 {
-    cout << d_indent << setw(2) << ++d_number << ": " << line << '\n';
+    nl();
+    cout << d_indent << setw(2) << ++d_number << ": " << line;
 }
